===============================
dbaas-zabbix
===============================

.. image:: https://badge.fury.io/py/dbaas-zabbix.png
    :target: http://badge.fury.io/py/dbaas-zabbix
    
.. image:: https://travis-ci.org/felippemr/dbaas-zabbix.png?branch=master
        :target: https://travis-ci.org/felippemr/dbaas-zabbix

.. image:: https://pypip.in/d/dbaas-zabbix/badge.png
        :target: https://pypi.python.org/pypi/dbaas-zabbix


A Zabbix Integration for DBaaS.

* Free software: BSD license
* Documentation: http://dbaas-zabbix.rtfd.org.

Features
--------

* TODO